@@ -173,9 +173,16 @@ class Users(object):
 				  // Handle error
 				});
 		"""
-		decoded_token = auth.verify_id_token(id_token)
-		uid = decoded_token['uid']
-		return uid
+		try:
+			decoded_token = auth.verify_id_token(id_token)
+			uid = decoded_token['uid']
+			if uid == None: success = False
+			else: success = True
+		except: success = False
+		if success:
+			return r3sponse.success_response("You are signed in.", {"uid":uid})
+		else:
+			return r3sponse.error_response("You are not signed in.")
 
 		#
 
