@@ -29,9 +29,13 @@ class users():
 				return r3sponse.error_response("Set the firebase of the requests.users class. [fir3base.requests.users.firebase = your_firebase_object", django=True)
 
 			# make request.
-			return firebase.users.create_user(
+			response = firebase.users.create(
 				name=parameters["name"],
 				email=parameters["email"],
 				password=parameters["password"],
 				verify_password=parameters["verify_password"],
 			)
+			try:
+				if response["success"]: del response["user"]
+			except KeyError: a=1
+			return JsonResponse(response)
